summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/examples/RtEC/MCast
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/examples/RtEC/MCast')
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/AddrServer.cpp2
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/AddrServer.h2
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/Consumer.cpp22
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/Consumer.h8
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/MCast.cpp66
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/Supplier.cpp24
-rw-r--r--TAO/orbsvcs/examples/RtEC/MCast/Supplier.h8
7 files changed, 66 insertions, 66 deletions
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.cpp b/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.cpp
index bfa2b4e8bd8..05fd4d9c983 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.cpp
+++ b/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.cpp
@@ -12,7 +12,7 @@ AddrServer::AddrServer (const RtecUDPAdmin::UDP_Addr& addr)
void
AddrServer::get_addr (const RtecEventComm::EventHeader&,
RtecUDPAdmin::UDP_Addr_out addr
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
addr = this->addr_;
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.h b/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.h
index fc3610771df..72e99b0d205 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.h
+++ b/TAO/orbsvcs/examples/RtEC/MCast/AddrServer.h
@@ -41,7 +41,7 @@ public:
// = The RtecUDPAdmin::AddrServer methods
virtual void get_addr (const RtecEventComm::EventHeader& header,
RtecUDPAdmin::UDP_Addr_out addr
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
private:
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/Consumer.cpp b/TAO/orbsvcs/examples/RtEC/MCast/Consumer.cpp
index c6e79b3ef6b..ff393428e06 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/Consumer.cpp
+++ b/TAO/orbsvcs/examples/RtEC/MCast/Consumer.cpp
@@ -13,14 +13,14 @@ Consumer::Consumer (void)
void
Consumer::connect (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->proxy_ =
- consumer_admin->obtain_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ consumer_admin->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
RtecEventComm::PushConsumer_var me =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Simple subscription, but usually the helper classes in
@@ -40,17 +40,17 @@ Consumer::connect (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
h1.source = ACE_ES_EVENT_SOURCE_ANY; // Any source is OK
this->proxy_->connect_push_consumer (me.in (), qos
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_TRY
{
// Disconnect from the proxy
- this->proxy_->disconnect_push_supplier (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->proxy_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -62,20 +62,20 @@ Consumer::disconnect (TAO_ENV_SINGLE_ARG_DECL)
// Deactivate this object
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Get the Object Id used for the servant..
PortableServer::ObjectId_var oid =
- poa->servant_to_id (this TAO_ENV_ARG_PARAMETER);
+ poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
// Deactivate the object
- poa->deactivate_object (oid.in () TAO_ENV_ARG_PARAMETER);
+ poa->deactivate_object (oid.in () ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
Consumer::push (const RtecEventComm::EventSet& events
- TAO_ENV_ARG_DECL_NOT_USED)
+ ACE_ENV_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
if (events.length () == 0)
@@ -95,7 +95,7 @@ Consumer::push (const RtecEventComm::EventSet& events
}
void
-Consumer::disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
}
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/Consumer.h b/TAO/orbsvcs/examples/RtEC/MCast/Consumer.h
index c71328b15d4..536404b824b 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/Consumer.h
+++ b/TAO/orbsvcs/examples/RtEC/MCast/Consumer.h
@@ -38,18 +38,18 @@ public:
// Constructor
void connect (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Connect to the Event Channel
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the event channel
// = The RtecEventComm::PushConsumer methods
virtual void push (const RtecEventComm::EventSet& events
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
- virtual void disconnect_push_consumer (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+ virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
// The skeleton methods.
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/Supplier.cpp b/TAO/orbsvcs/examples/RtEC/MCast/Supplier.cpp
index 1904326e03e..2572716d1e8 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/Supplier.cpp
+++ b/TAO/orbsvcs/examples/RtEC/MCast/Supplier.cpp
@@ -12,14 +12,14 @@ Supplier::Supplier (void)
void
Supplier::connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin
- TAO_ENV_ARG_DECL)
+ ACE_ENV_ARG_DECL)
{
this->proxy_ =
- supplier_admin->obtain_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ supplier_admin->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
RtecEventComm::PushSupplier_var me =
- this->_this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
// Simple publication, but usually the helper classes in
@@ -34,17 +34,17 @@ Supplier::connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin
h0.source = 1; // first free event source
this->proxy_->connect_push_supplier (me.in (), qos
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::disconnect (ACE_ENV_SINGLE_ARG_DECL)
{
// Disconnect from the EC
ACE_TRY
{
- this->proxy_->disconnect_push_consumer (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->proxy_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -53,17 +53,17 @@ Supplier::disconnect (TAO_ENV_SINGLE_ARG_DECL)
ACE_ENDTRY;
PortableServer::POA_var poa =
- this->_default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_CHECK;
PortableServer::ObjectId_var id =
- poa->servant_to_id (this TAO_ENV_ARG_PARAMETER);
+ poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
- poa->deactivate_object (id.in () TAO_ENV_ARG_PARAMETER);
+ poa->deactivate_object (id.in () ACE_ENV_ARG_PARAMETER);
ACE_CHECK;
}
void
-Supplier::perform_push (TAO_ENV_SINGLE_ARG_DECL)
+Supplier::perform_push (ACE_ENV_SINGLE_ARG_DECL)
{
ACE_TRY
{
@@ -75,7 +75,7 @@ Supplier::perform_push (TAO_ENV_SINGLE_ARG_DECL)
// Avoid loops throught the event channel federations
event[0].header.ttl = 1;
- this->proxy_->push (event TAO_ENV_ARG_PARAMETER);
+ this->proxy_->push (event ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_CATCHANY
@@ -85,7 +85,7 @@ Supplier::perform_push (TAO_ENV_SINGLE_ARG_DECL)
}
void
-Supplier::disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+Supplier::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException))
{
}
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/Supplier.h b/TAO/orbsvcs/examples/RtEC/MCast/Supplier.h
index a8d6c6ff31d..7c591f5fdb7 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/Supplier.h
+++ b/TAO/orbsvcs/examples/RtEC/MCast/Supplier.h
@@ -39,18 +39,18 @@ public:
// Constructor
void connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin
- TAO_ENV_ARG_DECL);
+ ACE_ENV_ARG_DECL);
// Connect to the event channel
- void disconnect (TAO_ENV_SINGLE_ARG_DECL);
+ void disconnect (ACE_ENV_SINGLE_ARG_DECL);
// Disconnect from the event channel
- void perform_push (TAO_ENV_SINGLE_ARG_DECL);
+ void perform_push (ACE_ENV_SINGLE_ARG_DECL);
// Push a single event
// = The RtecEventComm::PushSupplier methods
- virtual void disconnect_push_supplier (TAO_ENV_SINGLE_ARG_DECL_NOT_USED)
+ virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
ACE_THROW_SPEC ((CORBA::SystemException));
// The skeleton methods.
diff --git a/TAO/orbsvcs/examples/RtEC/MCast/MCast.cpp b/TAO/orbsvcs/examples/RtEC/MCast/MCast.cpp
index 82df7818a72..6dabe408305 100644
--- a/TAO/orbsvcs/examples/RtEC/MCast/MCast.cpp
+++ b/TAO/orbsvcs/examples/RtEC/MCast/MCast.cpp
@@ -44,18 +44,18 @@ main (int argc, char* argv[])
//
// If your platform supports native exceptions, and TAO was compiled
// with native exception support then you can simply use try/catch
// and avoid the TAO_ENV_SINGLE_ARG_PARAMETER argument.
// Unfortunately many embedded systems cannot use exceptions due to
// the space and time overhead.
//
- TAO_ENV_DECLARE_NEW_ENV;
+ ACE_DECLARE_NEW_CORBA_ENV;
ACE_TRY
{
// **************** HERE STARTS THE ORB SETUP
// Create the ORB, pass the argv list for parsing.
CORBA::ORB_var orb =
- CORBA::ORB_init (argc, argv, "" TAO_ENV_ARG_PARAMETER);
+ CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Parse the arguments, you usually want to do this after
@@ -73,15 +73,15 @@ main (int argc, char* argv[])
// The POA starts in the holding state, if it is not activated
// it will not process any requests.
CORBA::Object_var object =
- orb->resolve_initial_references ("RootPOA" TAO_ENV_ARG_PARAMETER);
+ orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POA_var poa =
- PortableServer::POA::_narrow (object.in () TAO_ENV_ARG_PARAMETER);
+ PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
PortableServer::POAManager_var poa_manager =
- poa->the_POAManager (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- poa_manager->activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// **************** THAT COMPLETS THE ORB SETUP
@@ -104,14 +104,14 @@ main (int argc, char* argv[])
// that may involve creating some threads.
// But it should always be invoked because several internal data
// structures are initialized at that point.
- ec_impl.activate (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ec_impl.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// The event channel is activated as any other CORBA servant.
// In this case we use the simple implicit activation with the
// RootPOA
RtecEventChannelAdmin::EventChannel_var event_channel =
- ec_impl._this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ec_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// **************** THAT COMPLETES THE LOCAL EVENT CHANNEL SETUP
@@ -148,7 +148,7 @@ main (int argc, char* argv[])
// Now we create and activate the servant
AddrServer as_impl (addr);
RtecUDPAdmin::AddrServer_var address_server =
- as_impl._this (TAO_ENV_SINGLE_ARG_PARAMETER);
+ as_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// We need a local socket to send the data, open it and check
@@ -165,7 +165,7 @@ main (int argc, char* argv[])
sender.init (event_channel.in (),
address_server.in (),
&endpoint
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Now we connect the sender as a consumer of events, it will
@@ -180,7 +180,7 @@ main (int argc, char* argv[])
sub.dependencies[0].event.header.source =
ACE_ES_EVENT_SOURCE_ANY; // Any source is OK
- sender.open (sub TAO_ENV_ARG_PARAMETER);
+ sender.open (sub ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// To receive events we need to setup an event handler:
@@ -198,7 +198,7 @@ main (int argc, char* argv[])
// Then it register for the multicast groups that carry those
// events:
int r = mcast_eh.open (event_channel.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
if (r == -1)
{
@@ -222,7 +222,7 @@ main (int argc, char* argv[])
orb->orb_core ()->reactor (),
expire,
max_expiration_count
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// The Receiver is also a supplier of events. The exact type of
@@ -242,7 +242,7 @@ main (int argc, char* argv[])
pub.publications[0].event.header.source = ACE_ES_EVENT_SOURCE_ANY;
pub.is_gateway = 1;
- receiver.open (pub TAO_ENV_ARG_PARAMETER);
+ receiver.open (pub ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// **************** THAT COMPLETES THE FEDERATION SETUP
@@ -253,19 +253,19 @@ main (int argc, char* argv[])
// channel
Consumer consumer;
RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin =
- event_channel->for_consumers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
consumer.connect (consumer_admin.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// And now create a supplier
Supplier supplier;
RtecEventChannelAdmin::SupplierAdmin_var supplier_admin =
- event_channel->for_suppliers (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
supplier.connect (supplier_admin.in ()
- TAO_ENV_ARG_PARAMETER);
+ ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// **************** THAT COMPLETES THE CLIENT SETUP
@@ -278,7 +278,7 @@ main (int argc, char* argv[])
for (int i = 0; i != 1000; ++i)
{
CORBA::Boolean there_is_work =
- orb->work_pending (TAO_ENV_SINGLE_ARG_PARAMETER);
+ orb->work_pending (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
if (there_is_work)
{
@@ -287,12 +287,12 @@ main (int argc, char* argv[])
// perform_work() or work_pending(), so just calling
// them results in a spin loop.
ACE_Time_Value tv (0, 50000);
- orb->perform_work (tv TAO_ENV_ARG_PARAMETER);
+ orb->perform_work (tv ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
ACE_Time_Value tv (0, 100000);
ACE_OS::sleep (tv);
- supplier.perform_push (TAO_ENV_SINGLE_ARG_PARAMETER);
+ supplier.perform_push (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
}
@@ -301,16 +301,16 @@ main (int argc, char* argv[])
// **************** HERE STARTS THE CLEANUP CODE
// First the easy ones
- supplier.disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ supplier.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- consumer.disconnect (TAO_ENV_SINGLE_ARG_PARAMETER);
+ consumer.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Now let us close the Receiver
- receiver.close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ receiver.close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
- r = mcast_eh.close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ r = mcast_eh.close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
if (r == -1)
{
@@ -319,13 +319,13 @@ main (int argc, char* argv[])
}
// And also close the sender of events
- sender.close (TAO_ENV_SINGLE_ARG_PARAMETER);
+ sender.close (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// The event channel must be destroyed, so it can release its
// resources, and inform all the clients that are still
// connected that it is going away.
- event_channel->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ event_channel->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Deactivating the event channel implementation is not strictly
@@ -337,24 +337,24 @@ main (int argc, char* argv[])
// is the root POA, but the code is more robust if we don't
// rely on that.
PortableServer::POA_var poa =
- ec_impl._default_POA (TAO_ENV_SINGLE_ARG_PARAMETER);
+ ec_impl._default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// Get the Object Id used for the servant..
PortableServer::ObjectId_var oid =
- poa->servant_to_id (&ec_impl TAO_ENV_ARG_PARAMETER);
+ poa->servant_to_id (&ec_impl ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Deactivate the object
- poa->deactivate_object (oid.in () TAO_ENV_ARG_PARAMETER);
+ poa->deactivate_object (oid.in () ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
}
// Now we can destroy the POA, the flags mean that we want to
// wait until the POA is really destroyed
- poa->destroy (1, 1 TAO_ENV_ARG_PARAMETER);
+ poa->destroy (1, 1 ACE_ENV_ARG_PARAMETER);
ACE_TRY_CHECK;
// Finally destroy the ORB
- orb->destroy (TAO_ENV_SINGLE_ARG_PARAMETER);
+ orb->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
ACE_TRY_CHECK;
// **************** THAT COMPLETES THE CLEANUP CODE
@@ -44,18 +44,18 @@ main (int argc, char* argv[])
// If your platform supports native exceptions, and TAO was compiled
// with native exception support then you can simply use try/catch
- // and avoid the TAO_ENV_SINGLE_ARG_PARAMETER argument.
+ // and avoid the ACE_ENV_SINGLE_ARG_PARAMETER argument.
// Unfortunately many embedded systems cannot use exceptions due to
// the space and time overhead.